@@ -11,7 +11,7 @@ def create(
         resourceName: str
     ):
     url = "http://sdt-api.qcc.svc.cluster.local"
-    url_path = f"{url}/qcc/job/notebook"
+    url_path = f"{url}/qcc/notebook/job"
 
     headers = {
         "Content-Type": "application/json",
